import random
import subprocess
import os, sys, getopt 
import time
# import logging
import spidev as SPI
sys.path.append("..")
from lib import LCD_1inch28
from PIL import Image,ImageDraw,ImageFont
from random import seed
from random import randint
import board
import digitalio
import adafruit_lis3dh

def main():
    # turn on LCD backlight
    os.system("raspi-gpio set 24 op pn dh")
    # set screen type 
    disp = LCD_1inch28.LCD_1inch28()
    # Initialize library.
    disp.Init()
    # Clear display.
    disp.clear()

    image = Image.open('/home/pi/magic8/tiles/AskaQuestion.jpg')
    disp.ShowImage(image)

    # set PCM required pins 
    os.system("raspi-gpio set 18 a0")
    os.system("raspi-gpio set 19 a0")
    os.system("raspi-gpio set 20 a0")
    os.system("raspi-gpio set 21 a0")

    # play continuous tone  to eliminate pops between messages
    os.system("aplay -t raw -r 48000 -c 2 -f S16_LE /dev/zero &")

    # play opening message
    os.system("mplayer -volume 23 /home/pi/magic8/waves/YESORNO.wav > /dev/null 2>&1")

    # set up accellerator board
    i2c = board.I2C()
    # set interrup pin
    int1 = digitalio.DigitalInOut(board.D6)
    lis3dh = adafruit_lis3dh.LIS3DH_I2C(i2c, int1=int1)
    lis3dh.range = adafruit_lis3dh.RANGE_2_G

    # current ball orientation
    globestate = "number-up"
    #  switch set if ball has been turned from number up to number down at least once
    flippedNumberDown = "no"
    # switch set if ball has been  turned from number down to number up at least once
    flippedNumberUp = "no"
    # switch set if ball has been shaken at least once
    shaken = "no"
    #  switch set if ball has been resting number up
    firsttime = "yes"
    # switch set when criteria have been met
    tellfortune = "no"

    # start timeout clock
    startTime = time.time()

    # run continually
    while True:
        # retrieve orientation information
        x, y, z = lis3dh.acceleration

        if z > 0 and globestate == "number-up":
            globestate = "number-down"
            flippedNumberDown = "yes"
            print("Flipped to Number Down")
        elif z < 0 and globestate == "number-down":
            globestate = "number-up"
            flippedNumberUp  = "yes"
            print("Flipped to Number Up")

        if lis3dh.shake(shake_threshold=11):
            shaken = "yes"
            print("Shaken")

        # first time criteria check
        if firsttime == "yes" and  globestate == "number-down" and shaken=="yes":
                tellfortune = "yes"

        # the rest of the time criteria check
        if firsttime == "no" and globestate == "number-down" and flippedNumberUp == "yes" and shaken == "yes":
                tellfortune = "yes"

        if tellfortune == "yes":
            # turn lcd backlight back on in case of timeout
            os.system("raspi-gpio set 24 op pn dh")

            # reset switches
            shaken = "no"
            flippedNumberDown =  "no"
            flippedNumberUp = "no"
            tellfortune = "no"
            firsttime= "no"

            # reseed  random
            random.seed(time.time())

            # get random integer from 1 to 40
            value = str(randint(1, 40))
            r = value.zfill(3)
            print ("R value: " + r)

            # create absolute tile name
            imagename = "/home/pi/magic8/tiles/TILE" + r + ".jpg"
            print("Image name " + imagename)

            # show image
            image = Image.open(imagename)
            disp.ShowImage(image)

            # create absolute wave name
            voicename = "/home/pi/magic8/waves/WAVE" + r + ".wav"
            print("Voice name " + voicename)

            # play wave
            os.system("mplayer -volume 23 " + voicename + " > /dev/null 2>&1")

            # start timeout counter over
            startTime = time.time()

        # calculate idol time
        endTime = time.time()
        duration = endTime - startTime

        # timeout in seconds
        if duration > 600:
            print("Timeout message")
            os.system("raspi-gpio set 24 op pn dl")
            os.system("mplayer -volume 23 /home/pi/magic8/waves/YESORNO.wav > /dev/null 2>&1")
            startTime = time.time()

main()
